@@ -4,8 +4,8 @@ removeFormulaFormatting <- function(form)
   f <- if (grepl("\\+",form)) unlist(strsplit(form, "\\+")) else form
   n.f <- length(f)
   for (i in 1:n.f) {
-    f[i] <- gsub("lp\\(([[:alnum:]]+).*\\)", "\\1", f[i])
-    f[i] <- gsub("s\\(([[:alnum:]]+).*\\)", "\\1", f[i])
+    f[i] <- gsub("\blp\\(([[:alnum:]]+).*\\)", "\\1", f[i])
+    f[i] <- gsub("\bs\\(([[:alnum:]]+).*\\)", "\\1", f[i])
   }
   val <- paste(f,collapse=" + ")
   val <- gsub("()","",val)
