@@ -7,6 +7,7 @@ visreg <- function(fit, xvar, by, breaks=4, type=c("conditional","effect"), tran
   if (!missing(by) & !missing(cond)) stop("Cannot specify 'by' and 'cond' simultaneously")
   if (scale=="response") trans <- family(fit)$linkinv
   
+  r <- residuals(fit)
   f <- setupF(fit)
   if (missing(xvar)) xvar <- names(f)[-1]
   for (i in 1:length(xvar)){if (!is.element(xvar[i],names(f))) stop(paste(xvar[i],"not in model"))}
@@ -17,6 +18,7 @@ visreg <- function(fit, xvar, by, breaks=4, type=c("conditional","effect"), tran
     warning("'By' variable has too few unique values and has been coerced to a factor")
   }
   if (attr(f,"needs.update")) fit <- update(fit,data=f)
+  fit$residuals <- r
   cond <- setupCond(cond,f,by,breaks)
   
   n.y <- if (class(fit)[1]=="mlm") ncol(coef(fit)) else 1
@@ -26,8 +28,7 @@ visreg <- function(fit, xvar, by, breaks=4, type=c("conditional","effect"), tran
     on.exit(devAskNewPage(oask))
   }
   
-  if (missing(by))
-  {
+  if (missing(by)) {
     v <- vector("list",length(xvar))
     for (i in 1:length(xvar))
     {
@@ -35,10 +36,8 @@ visreg <- function(fit, xvar, by, breaks=4, type=c("conditional","effect"), tran
     }
     names(v) <- xvar
     if (length(xvar)==1) v <- v[[1]]
-  }
-  else
-  {
+  } else {
     v <- visregLatticePlot(fit, f, xvar, nn, cond, type, trans, xtrans, alpha, jitter, partial, whitespace, by, strip.names, line.par, fill.par, points.par, ...)
   }
-  return(invisible(v))
+  invisible(v)
 }
